@@ -116,7 +116,7 @@ sub _request_headers_expanded {
 }
 
 our $_response_headers = [
-    { name => 'TrackingId', type => 'string', namespace => 'https://adapi.microsoft.com' }
+    { name => 'TrackingId', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' }
 ];
 
 our $_response_headers_expanded = {
