@@ -11,20 +11,24 @@ use Test::More;
 
 use Microsoft::AdCenter::CustomerManagementService;
 
-sub test_can_create_customer_management_service_and_set_all_fields : Test(5) {
+sub test_can_create_customer_management_service_and_set_all_fields : Test(7) {
     my $customer_management_service = Microsoft::AdCenter::CustomerManagementService->new
         ->EndPoint('somewhere')
+        ->ApplicationToken('application token')
+        ->DeveloperToken('developer token')
         ->Password('password')
-        ->UserAccessKey('user access key')
         ->UserName('user name')
+        ->TrackingId('tracking id')
     ;
 
     ok($customer_management_service);
 
     is($customer_management_service->EndPoint, 'somewhere', 'can get end point');
+    is($customer_management_service->ApplicationToken, 'application token', 'can get application token');
+    is($customer_management_service->DeveloperToken, 'developer token', 'can get developer token');
     is($customer_management_service->Password, 'password', 'can get password');
-    is($customer_management_service->UserAccessKey, 'user access key', 'can get user access key');
     is($customer_management_service->UserName, 'user name', 'can get user name');
+    is($customer_management_service->TrackingId, 'tracking id', 'can get tracking id');
 };
 
 1;
